#############################################################
######################Preparing data#########################
#############################################################

rm(list=ls())

################Loading packages#######################

library(msm) #load package for multistage Markov model
library(xtable)
#require(gdata)
library(descr)
library(DescTools)
library(manipulate)
library(doBy)
library(ggplot2)

################Setting work directory#################
setwd("/path/to/my/directory")


###############Read data from files###################
mydata<-read.csv("all data before AD.csv")

#full<-read.csv("full.csv") #separated states for each patient

###############Declare categorical variables##########
mydata$APOE4<-factor(mydata$APOE4)
mydata$DX<-factor(mydata$DX)
mydata$DXreal<-factor(mydata$DXreal)
mydata$PTGENDER<-factor(mydata$PTGENDER)

# full$APOE4<-factor(full$APOE4)
# full$DX<-factor(full$DX)
# full$DXreal<-factor(full$DXreal)

##############Table of transitions##############
print(xtable(statetable.msm(DX,ID,data=mydata),align="r|rrr",caption="Table of state transitions",label="tab:transition"),caption.placement = getOption("xtable.caption.placement", "top"),table.placement = getOption("xtable.table.placement", "t"))

#     to
# from  NC MCI  AD
#    1 705  29   0
#    2  14 699 108

q3<-rbind(c(0,0.2,0),c(0.2,0,.1),c(0,0,0))
rownames(q3)<-colnames(q3)<-c("NL","MCI","AD")

q33<-rbind(c(0,1,0),c(1,0,1),c(0,0,0))
rownames(q33)<-colnames(q33)<-c("NL","MCI","AD")


#################################################################
##############Markov model without any covariates################
#################################################################

ADNI.msm<-msm(DX~AGEreal,subject=ID,data=mydata,qmatrix=q3,death = TRUE,method="Nelder-Mead",control=list(maxit=20000))
#mydata$AGEadjt<-mydata$AGEreal-55
#ADNI.msm<-msm(DX~AGEadjt,subject=ID,data=mydata,qmatrix=q33,death = TRUE,method="Nelder-Mead",control=list(maxit=20000))


##############Estimates of coefficients
temp<-data.frame(ADNI.msm$estimates,row.names=c("q12","q21","q23"))
temp<-cbind(temp,exp(temp))
names(temp)<-c("beta0","exp(beta0)")
print(xtable(temp,digits=4,align="r|rr",caption="Table of Estimates for the model without covariates.",label="tab:Ewc"),caption.placement = getOption("xtable.caption.placement", "top"),table.placement = getOption("xtable.table.placement", "t"))

##############Estimated transition intensity

temp<-print(qmatrix.msm(ADNI.msm))

print(xtable(temp,digits=4,align="r|rrr",caption="Table of Qmatrices (Transition rates (per year)) for the model without covariates.",label="tab:Qwc"),caption.placement = getOption("xtable.caption.placement", "top"),table.placement = getOption("xtable.table.placement", "t"))

##############Estimated transition probability

vv1<-print(pmatrix.msm(ADNI.msm,t=2,ci="normal"))
vv2<-print(pmatrix.msm(ADNI.msm,t=4,ci="normal"))

print(xtable(vv1,digits=4,caption="Estimited transition probability matrix at 2 years for the model without covariates.",label="tab:Pwc_t2"),
  caption.placement = getOption("xtable.caption.placement", "top"),table.placement = getOption("xtable.table.placement", "t"))

print(xtable(vv2,digits=4,caption="Estimited transition probability matrix at 4 years for the model without covariates.",label="tab:Pwc_t4"),
  caption.placement = getOption("xtable.caption.placement", "top"),table.placement = getOption("xtable.table.placement", "t"))

##############Estimated sojourn time
print(xtable(sojourn.msm(ADNI.msm),digits=4,caption="Table of sojourn time for the model without covariates.",label="tab:Swc"),caption.placement = getOption("xtable.caption.placement", "top"),table.placement = getOption("xtable.table.placement", "t"))

##############Survival probability plot

setEPS()
postscript("survivalwcf1_adj.eps")

par(font=2,font.lab=2,font.axis=2,cex=1.2,bty = "n")
par(mar=c(5.1, 4.1, 4.1, 8.1), xpd=TRUE)
plot.survfit.msm(ADNI.msm,from=1,legend.pos=c(100,100),mark.time = TRUE,conf.int=FALSE,ci="normal",xlab="Time on study (years)",xlim=c(0, 8),lwd=4,lty.ci=3,lwd.ci=4,lwd.surv=4,axes=F,cex.lab=1.2,cex=1.2)
legend("topright", inset=c(-0.45,0),legend=c("Fitted","Fitted CI","Empirical"),lty=c(1,2,3),col=c("red","red","blue"),lwd=4)
axis(1,lwd=4,cex.axis=1.2)
axis(2,lwd=4,cex.axis=1.2)

dev.off()

setEPS()
postscript("survivalwcf2_adj.eps")

par(font=2,font.lab=2,font.axis=2,cex=1.2,bty = "n")
par(mar=c(5.1, 4.1, 4.1, 8.1), xpd=TRUE)
plot.survfit.msm(ADNI.msm,from=2,legend.pos=c(100,100),mark.time = TRUE,conf.int=FALSE,ci="normal",xlab="Time on study (years)",xlim=c(0, 8),lwd=4,lty.ci=3,lwd.ci=4,lwd.surv=4,axes=F,cex.lab=1.2,cex=1.2)
legend("topright", inset=c(-0.45,0),legend=c("Fitted","Fitted CI","Empirical"),lty=c(1,2,3),col=c("red","red","blue"),lwd=4)
axis(1,lwd=4,cex.axis=1.2)
axis(2,lwd=4,cex.axis=1.2)

dev.off()


#################################################################
##############Markov model with AGE################
#################################################################

ADNI.AGE.msm<-msm(DX~Years_bl,subject=ID,data=mydata,qmatrix=q3,covariates=~AGEreal,method="Nelder-Mead",control=list(maxit=20000))
lrtest.msm(ADNI.msm,ADNI.AGE.msm)

ageseq<-seq(55,90,5)
f1<-function(age)
{
qmatrix.msm(ADNI.AGE.msm,covariates=list(AGEreal=age),ci="normal")
}
Y<-lapply(ageseq,f1)
q12<-q21<-q23<-matrix(0,length(ageseq),2)
for(i in 1:length(ageseq))
{
q12[i,1]<-Y[[i]]$estimates[1,2]
q21[i,1]<-Y[[i]]$estimates[2,1]
q23[i,1]<-Y[[i]]$estimates[2,3]
q12[i,2]<-Y[[i]]$SE[1,2]
q21[i,2]<-Y[[i]]$SE[2,1]
q23[i,2]<-Y[[i]]$SE[2,3]

}


setEPS()
postscript("intensitybyage.eps")

par(font=2,font.lab=2,font.axis=2,cex=1.5,bty = "n")
par(mar=c(4.1, 4.1, 2.1, 5.1), xpd=TRUE)
plot(ageseq,q12[,1],xlim=c(55,90),ylim=c(0,0.3),xlab="Age (years)", ylab="Transition rate",lwd=4,type='b',lty=1,,pch=1,col='red',axes=F,cex.lab=1.2)
lines(ageseq,q21[,1],type='b',lty=2,pch=2,col='blue',lwd=4)
lines(ageseq,q23[,1],type='b',lty=3,pch=3,col='purple',lwd=4)
arrows(ageseq, q12[,1]-q12[,2],ageseq, q12[,1]+q12[,2], length=0.05, angle=90, code=3,col="red",lwd=2)
arrows(ageseq, q21[,1]-q21[,2], ageseq, q21[,1]+q21[,2], length=0.05, angle=90, code=3,col="blue",lwd=2)
arrows(ageseq, q23[,1]-q23[,2], ageseq, q23[,1]+q23[,2], length=0.05, angle=90, code=3,col="purple",lwd=2)
axis(1,lwd=4,cex.axis=1.2)
axis(2,lwd=4,cex.axis=1.2)
legend("topright", inset=c(-0.3,0), legend=c("NC-MCI","MCI-NC","MCI-AD"), pch=c(1,2,3),lty=c(1,2,3),col=c('red','blue','purple'),title="Group",lwd=4)

dev.off()

#################################################################
##############Markov model with Interaction################
#################################################################
attach(mydata)
Xdesign<-matrix(0,length(APOE4),4)
for(i in 1:length(APOE4))
{   
  if(PTGENDER[i]==0 & APOE4[i]==0)
  {
    Xdesign[i,]<-c(1,0,0,0)
  }
  if(PTGENDER[i]==1 & APOE4[i]==0)
  {
    Xdesign[i,]<-c(0,1,0,0)
  }
   if(PTGENDER[i]==0 & (APOE4[i]==1 || APOE4[i]==2 ))
  {
    Xdesign[i,]<-c(0,0,1,0)
  }
   if(PTGENDER[i]==1 & (APOE4[i]==1 || APOE4[i]==2 ))
  {
    Xdesign[i,]<-c(0,0,0,1)
  }
}
detach(mydata)
colnames(Xdesign)<-c("femaleAPOE4_0","maleAPOE4_0","femaleAPOE4_1","maleAPOE4_1")
newdata<-cbind(mydata,Xdesign)
attach(newdata)

ADNI.inter.msm<-msm(DX~Years_bl,subject=ID,data=newdata,covariates=~maleAPOE4_0+femaleAPOE4_1+maleAPOE4_1,qmatrix=q3,method="Nelder-Mead",control=list(maxit=20000))

detach(newdata)

lrtest.msm(ADNI.msm,ADNI.inter.msm)

####################Estimates of coefficient

temp<-matrix(ADNI.inter.msm$estimates,3,4)
temp<-data.frame(temp,row.names=c("q12","q21","q23"))
names(temp)<-c("beta0","beta1","beta2","beta3")

print(xtable(temp,digits=4,align="r|rrrr",caption="Table of Estimates for model with covariate APOE4",label="tab:betahmmc1"),caption.placement = getOption("xtable.caption.placement", "top"),table.placement = getOption("xtable.table.placement", "t"))

####################Estimates of transition intensity


###APOE4 positive
temp<-print(qmatrix.msm(ADNI.inter.msm,covariates=list(maleAPOE4_0=0,femaleAPOE4_1=0,maleAPOE4_1=0)))
print(xtable(temp,digits=4,align="r|rrr",caption="Table of Qmatrices (Transition rates(per year)) for the model with interaction of gender and ApoE4, when ApoE4 is negative and gender is female.",label="tab:Qapoe41"),caption.placement = getOption("xtable.caption.placement", "top"),table.placement = getOption("xtable.table.placement", "t"))

###APOE4 negative
temp<-print(qmatrix.msm(ADNI.inter.msm,covariates=list(maleAPOE4_0=1,femaleAPOE4_1=0,maleAPOE4_1=0)))
print(xtable(temp,digits=4,align="r|rrr",caption="Table of Qmatrices (Transition rates (per year)) for the model with interaction of gender and ApoE4, when ApoE4 is negative and gender is male.",label="tab:Qapoe40"),caption.placement = getOption("xtable.caption.placement", "top"),table.placement = getOption("xtable.table.placement", "t"))

temp<-print(qmatrix.msm(ADNI.inter.msm,covariates=list(maleAPOE4_0=0,femaleAPOE4_1=1,maleAPOE4_1=0)))
print(xtable(temp,digits=4,align="r|rrr",caption="Table of Qmatrices (Transition rates (per year)) for the model with interaction of gender and ApoE4, when ApoE4 is positive and gender is female.",label="tab:Qapoe40"),caption.placement = getOption("xtable.caption.placement", "top"),table.placement = getOption("xtable.table.placement", "t"))

temp<-print(qmatrix.msm(ADNI.inter.msm,covariates=list(maleAPOE4_0=0,femaleAPOE4_1=0,maleAPOE4_1=1)))
print(xtable(temp,digits=4,align="r|rrr",caption="Table of Qmatrices (Transition rates (per year)) for the model with interaction of gender and ApoE4, when ApoE4 is positive and gender is male.",label="tab:Qapoe40"),caption.placement = getOption("xtable.caption.placement", "top"),table.placement = getOption("xtable.table.placement", "t"))


###APOE4 negative, gender female
tseq<-seq(0,4,0.5)
f0<-function(t)
{
pmatrix.msm(ADNI.inter.msm,t=t,covariates=list(maleAPOE4_0=0,femaleAPOE4_1=0,maleAPOE4_1=0),ci="normal")
}
Y<-lapply(tseq,f0)
q12<-q21<-q23<-matrix(0,length(tseq),2)
for(i in 1:length(tseq))
{
q12[i,1]<-Y[[i]]$estimates[1,2]
q21[i,1]<-Y[[i]]$estimates[2,1]
q23[i,1]<-Y[[i]]$estimates[2,3]
q12[i,2]<-(Y[[i]]$U[1,2]-Y[[i]]$L[1,2])/(2*1.96)
q21[i,2]<-(Y[[i]]$U[2,1]-Y[[i]]$L[2,1])/(2*1.96)
q23[i,2]<-(Y[[i]]$U[2,3]-Y[[i]]$L[2,3])/(2*1.96)

}

setEPS()
postscript("probabilityAPOE40gender0.eps")

par(font=2,font.lab=2,font.axis=2,cex=1.2,bty = "n")
par(mar=c(4.1, 4.1, 2.1, 5.1), xpd=TRUE)
plot(tseq,q12[,1],xlim=c(0,4),ylim=c(0,0.9),xlab="Time on study (years)", ylab="Transition probability",lwd=4,type='b',lty=1,pch=1,col='red',axes=F,cex.lab=1.2,cex=1.2)
#lines(tseq,q21[,1],type='b',lty=2,pch=2,col='blue',lwd=4)
lines(tseq,q23[,1],type='b',lty=3,pch=3,col='purple',lwd=4)
arrows(tseq, q12[,1]-q12[,2],tseq, q12[,1]+q12[,2], length=0.05, angle=90, code=3,col="red",lwd=2)
#arrows(tseq, q21[,1]-q21[,2], tseq, q21[,1]+q21[,2], length=0.05, angle=90, code=3,col="blue",lwd=2)
arrows(tseq, q23[,1]-q23[,2], tseq, q23[,1]+q23[,2], length=0.05, angle=90, code=3,col="purple",lwd=2)
axis(1,lwd=4,cex.axis=1.2)
axis(2,lwd=4,cex.axis=1.2)
legend(x=c(0.1,0.4),y=c(0.7,0.9),legend=c("NC-MCI","MCI-AD"), pch=c(1,3),lty=c(1,3),col=c('red','purple'),title="Group",lwd=4, bty="n")

dev.off()

###APOE4 negative, gender male
tseq<-seq(0,4,0.5)
f0<-function(t)
{
pmatrix.msm(ADNI.inter.msm,t=t,covariates=list(maleAPOE4_0=1,femaleAPOE4_1=0,maleAPOE4_1=0),ci="normal")
}
Y<-lapply(tseq,f0)
q12<-q21<-q23<-matrix(0,length(tseq),2)
for(i in 1:length(tseq))
{
q12[i,1]<-Y[[i]]$estimates[1,2]
q21[i,1]<-Y[[i]]$estimates[2,1]
q23[i,1]<-Y[[i]]$estimates[2,3]
q12[i,2]<-(Y[[i]]$U[1,2]-Y[[i]]$L[1,2])/(2*1.96)
q21[i,2]<-(Y[[i]]$U[2,1]-Y[[i]]$L[2,1])/(2*1.96)
q23[i,2]<-(Y[[i]]$U[2,3]-Y[[i]]$L[2,3])/(2*1.96)
}

setEPS()
postscript("probabilityAPOE40gender1.eps")

par(font=2,font.lab=2,font.axis=2,cex=1.2,bty = "n")
par(mar=c(4.1, 4.1, 2.1, 5.1), xpd=TRUE)
plot(tseq,q12[,1],xlim=c(0,4),ylim=c(0,0.9),xlab="Time on study (years)", ylab="Transition probability",lwd=4,type='b',lty=1,pch=1,col='red',axes=F,cex.lab=1.2,cex=1.2)
#lines(tseq,q21[,1],type='b',lty=2,pch=2,col='blue',lwd=4)
lines(tseq,q23[,1],type='b',lty=3,pch=3,col='purple',lwd=4)
arrows(tseq, q12[,1]-q12[,2],tseq, q12[,1]+q12[,2], length=0.05, angle=90, code=3,col="red",lwd=2)
#arrows(tseq, q21[,1]-q21[,2], tseq, q21[,1]+q21[,2], length=0.05, angle=90, code=3,col="blue",lwd=2)
arrows(tseq, q23[,1]-q23[,2], tseq, q23[,1]+q23[,2], length=0.05, angle=90, code=3,col="purple",lwd=2)
axis(1,lwd=4,cex.axis=1.2)
axis(2,lwd=4,cex.axis=1.2)
legend(x=c(0.1,0.4),y=c(0.7,0.9), legend=c("NC-MCI","MCI-AD"), pch=c(1,3),lty=c(1,3),col=c('red','purple'),title="Group",lwd=4, bty="n")

dev.off()


###APOE4 positive, gender female
tseq<-seq(0,4,0.5)
f0<-function(t)
{
pmatrix.msm(ADNI.inter.msm,t=t,covariates=list(maleAPOE4_0=0,femaleAPOE4_1=1,maleAPOE4_1=0),ci="normal")
}
Y<-lapply(tseq,f0)
q12<-q21<-q23<-matrix(0,length(tseq),2)
for(i in 1:length(tseq))
{
q12[i,1]<-Y[[i]]$estimates[1,2]
q21[i,1]<-Y[[i]]$estimates[2,1]
q23[i,1]<-Y[[i]]$estimates[2,3]
q12[i,2]<-(Y[[i]]$U[1,2]-Y[[i]]$L[1,2])/(2*1.96)
q21[i,2]<-(Y[[i]]$U[2,1]-Y[[i]]$L[2,1])/(2*1.96)
q23[i,2]<-(Y[[i]]$U[2,3]-Y[[i]]$L[2,3])/(2*1.96)
}

setEPS()
postscript("probabilityAPOE41gender0.eps")

par(font=2,font.lab=2,font.axis=2,cex=1.2,bty = "n")
par(mar=c(4.1, 4.1, 2.1, 5.1), xpd=TRUE)
plot(tseq,q12[,1],xlim=c(0,4),ylim=c(0,0.9),xlab="Time on study (years)", ylab="Transition probability",lwd=4,type='b',lty=1,pch=1,col='red',axes=F,cex.lab=1.2,cex=1.2)
#lines(tseq,q21[,1],type='b',lty=2,pch=2,col='blue',lwd=4)
lines(tseq,q23[,1],type='b',lty=3,pch=3,col='purple',lwd=4)
arrows(tseq, q12[,1]-q12[,2],tseq, q12[,1]+q12[,2], length=0.05, angle=90, code=3,col="red",lwd=2)
#arrows(tseq, q21[,1]-q21[,2], tseq, q21[,1]+q21[,2], length=0.05, angle=90, code=3,col="blue",lwd=2)
arrows(tseq, q23[,1]-q23[,2], tseq, q23[,1]+q23[,2], length=0.05, angle=90, code=3,col="purple",lwd=2)
axis(1,lwd=4,cex.axis=1.2)
axis(2,lwd=4,cex.axis=1.2)
legend(x=c(0.1,0.4),y=c(0.7,0.9), legend=c("NC-MCI","MCI-AD"), pch=c(1,3),lty=c(1,3),col=c('red','purple'),title="Group",lwd=4, bty="n")

dev.off()


###APOE4 negative, gender male
tseq<-seq(0,4,0.5)
f0<-function(t)
{
pmatrix.msm(ADNI.inter.msm,t=t,covariates=list(maleAPOE4_0=0,femaleAPOE4_1=0,maleAPOE4_1=1),ci="normal")
}
Y<-lapply(tseq,f0)
q12<-q21<-q23<-matrix(0,length(tseq),2)
for(i in 1:length(tseq))
{
q12[i,1]<-Y[[i]]$estimates[1,2]
q21[i,1]<-Y[[i]]$estimates[2,1]
q23[i,1]<-Y[[i]]$estimates[2,3]
q12[i,2]<-(Y[[i]]$U[1,2]-Y[[i]]$L[1,2])/(2*1.96)
q21[i,2]<-(Y[[i]]$U[2,1]-Y[[i]]$L[2,1])/(2*1.96)
q23[i,2]<-(Y[[i]]$U[2,3]-Y[[i]]$L[2,3])/(2*1.96)
}

setEPS()
postscript("probabilityAPOE41gender1.eps")

par(font=2,font.lab=2,font.axis=2,cex=1.2,bty = "n")
par(mar=c(4.1, 4.1, 2.1, 5.1), xpd=TRUE)
plot(tseq,q12[,1],xlim=c(0,4),ylim=c(0,0.9),xlab="Time on study (years)", ylab="Transition probability",lwd=4,type='b',lty=1,pch=1,col='red',axes=F,cex.lab=1.2,cex=1.2)
#lines(tseq,q21[,1],type='b',lty=2,pch=2,col='blue',lwd=4)
lines(tseq,q23[,1],type='b',lty=3,pch=3,col='purple',lwd=4)
arrows(tseq, q12[,1]-q12[,2],tseq, q12[,1]+q12[,2], length=0.05, angle=90, code=3,col="red",lwd=2)
#arrows(tseq, q21[,1]-q21[,2], tseq, q21[,1]+q21[,2], length=0.05, angle=90, code=3,col="blue",lwd=2)
arrows(tseq, q23[,1]-q23[,2], tseq, q23[,1]+q23[,2], length=0.05, angle=90, code=3,col="purple",lwd=2)
axis(1,lwd=4,cex.axis=1.2)
axis(2,lwd=4,cex.axis=1.2)
legend(x=c(0.1,0.4),y=c(0.7,0.9), legend=c("NC-MCI","MCI-AD"), pch=c(1,3),lty=c(1,3),col=c('red','purple'),title="Group",lwd=4, bty="n")

dev.off()




#################################################################
##############Markov model with APOE4################
#################################################################

attach(mydata)
sum(is.na(APOE4))
levels(as.factor(APOE4))
Xdesign<-matrix(0,length(APOE4),2)
for(i in 1:length(APOE4))
{   
  if(APOE4[i]==0)
  {
    Xdesign[i,]<-c(1,0)
  }
  if(APOE4[i]==1 || APOE4[i]==2)
  {
    Xdesign[i,]<-c(0,1)
  }
}
detach(mydata)
colnames(Xdesign)<-c("APOE4_0","APOE4_1")
newdata<-cbind(mydata,Xdesign)
attach(newdata)

ADNI.APOE4.msm<-msm(DX~Years_bl,subject=ID,data=newdata,covariates=~APOE4_1,qmatrix=q3,method="Nelder-Mead",control=list(maxit=20000))

lrtest.msm(ADNI.msm,ADNI.APOE4.msm)

####################Estimates of coefficient

temp<-matrix(ADNI.APOE4.msm$estimates,3,2)
temp<-data.frame(temp,row.names=c("q12","q21","q23"))
names(temp)<-c("beta0","beta1")

print(xtable(temp,digits=4,align="r|rr",caption="Table of Estimates for model with covariate APOE4",label="tab:betahmmc1"),caption.placement = getOption("xtable.caption.placement", "top"),table.placement = getOption("xtable.table.placement", "t"))

####################Estimates of transition intensity


###APOE4 positive
temp<-print(qmatrix.msm(ADNI.APOE4.msm,covariates=list(APOE4_1=1)))
print(xtable(temp,digits=4,align="r|rrr",caption="Table of Qmatrices (Transition rates(per year)) for the model with covariate ApoE4, when ApoE4 is 1.",label="tab:Qapoe41"),caption.placement = getOption("xtable.caption.placement", "top"),table.placement = getOption("xtable.table.placement", "t"))

###APOE4 negative
temp<-print(qmatrix.msm(ADNI.APOE4.msm,covariates=list(APOE4_1=0)))
print(xtable(temp,digits=4,align="r|rrr",caption="Table of Qmatrices (Transition rates (per year)) for the model with covariate ApoE4, when ApoE4 is 0.",label="tab:Qapoe40"),caption.placement = getOption("xtable.caption.placement", "top"),table.placement = getOption("xtable.table.placement", "t"))

####################Estimates of transition probability


###APOE4 positive, at year 2
temp<-print(pmatrix.msm(ADNI.APOE4.msm,covariates=list(APOE4_1=1),t=2,ci="normal"))
print(xtable(temp,digits=4,align="r|rrr",caption="Table of Pmatrices (Transition Probability at year 2 for the model with covariate ApoE4, when ApoE4 is 1.)",label="tab:Papoe41"),caption.placement = getOption("xtable.caption.placement", "top"),table.placement = getOption("xtable.table.placement", "t"))

###APOE4 negative, at year 2
temp<-print(pmatrix.msm(ADNI.APOE4.msm,covariates=list(APOE4_1=0),t=2,ci="normal"))
print(xtable(temp,digits=4,align="r|rrr",caption="Table of Pmatrices (Transition Probability at year 2 for the model with covariate ApoE4, when ApoE4 is 0.) ",label="tab:Papoe40"),caption.placement = getOption("xtable.caption.placement", "top"),table.placement = getOption("xtable.table.placement", "t"))

###APOE4 positive, at year 4
temp<-print(pmatrix.msm(ADNI.APOE4.msm,covariates=list(APOE4_1=1),t=4,ci="normal"))
print(xtable(temp,digits=4,align="r|rrr",caption="Table of Pmatrices (Transition Probability at year 2 for the model with covariate ApoE4, when ApoE4 is 1.)",label="tab:Papoe41"),caption.placement = getOption("xtable.caption.placement", "top"),table.placement = getOption("xtable.table.placement", "t"))

###APOE4 negative, at year 4
temp<-print(pmatrix.msm(ADNI.APOE4.msm,covariates=list(APOE4_1=0),t=4,ci="normal"))
print(xtable(temp,digits=4,align="r|rrr",caption="Table of Pmatrices (Transition Probability at year 2 for the model with covariate ApoE4, when ApoE4 is 0.) ",label="tab:Papoe40"),caption.placement = getOption("xtable.caption.placement", "top"),table.placement = getOption("xtable.table.placement", "t"))


####################Estimates of mean sojourn time

###APOE4  positive
print(xtable(sojourn.msm(ADNI.APOE4.msm,covariates=list(APOE4_1=1)),digits=4,caption="Table of sojourn time for the model with covariate ApoE4, when ApoE4 is 1.",label="tab:Sapoe41"),caption.placement = getOption("xtable.caption.placement", "top"),table.placement = getOption("xtable.table.placement", "t"))

###APOE4 negative
print(xtable(sojourn.msm(ADNI.APOE4.msm,covariates=list(APOE4_1=0)),digits=4,caption="Table of sojourn time for the model with covariate ApoE4, when ApoE4 is 0.",label="tab:Sapoe40"),caption.placement = getOption("xtable.caption.placement", "top"),table.placement = getOption("xtable.table.placement", "t"))

#####################Transition probability plot


###APOE4 positive
tseq<-seq(0,4,0.5)
f0<-function(t)
{
pmatrix.msm(ADNI.APOE4.msm,t=t,covariates=list(APOE4_1=1),ci="normal")
}
Y<-lapply(tseq,f0)
q12<-q21<-q23<-matrix(0,length(tseq),2)
for(i in 1:length(tseq))
{
q12[i,1]<-Y[[i]]$estimates[1,2]
q21[i,1]<-Y[[i]]$estimates[2,1]
q23[i,1]<-Y[[i]]$estimates[2,3]
q12[i,2]<-(Y[[i]]$U[1,2]-Y[[i]]$L[1,2])/(2*1.96)
q21[i,2]<-(Y[[i]]$U[2,1]-Y[[i]]$L[2,1])/(2*1.96)
q23[i,2]<-(Y[[i]]$U[2,3]-Y[[i]]$L[2,3])/(2*1.96)

}

setEPS()
postscript("probabilityAPOE41.eps")

par(font=2,font.lab=2,font.axis=2,cex=1.2,bty = "n")
par(mar=c(4.1, 4.1, 2.1, 5.1), xpd=TRUE)
plot(tseq,q12[,1],xlim=c(0,4),ylim=c(0,0.8),xlab="Time on study (years)", ylab="Transition probability",lwd=4,type='b',lty=1,pch=1,col='red',axes=F,cex.lab=1.2,cex=1.2)
lines(tseq,q21[,1],type='b',lty=2,pch=2,col='blue',lwd=4)
lines(tseq,q23[,1],type='b',lty=3,pch=3,col='purple',lwd=4)
arrows(tseq, q12[,1]-q12[,2],tseq, q12[,1]+q12[,2], length=0.05, angle=90, code=3,col="red",lwd=2)
arrows(tseq, q21[,1]-q21[,2], tseq, q21[,1]+q21[,2], length=0.05, angle=90, code=3,col="blue",lwd=2)
arrows(tseq, q23[,1]-q23[,2], tseq, q23[,1]+q23[,2], length=0.05, angle=90, code=3,col="purple",lwd=2)
axis(1,lwd=4,cex.axis=1.2)
axis(2,lwd=4,cex.axis=1.2)
legend(x=c(0.1,0.4),y=c(0.6,0.8),legend=c("NC-MCI","MCI-NC","MCI-AD"), pch=c(1,2,3),lty=c(1,2,3),col=c('red','blue','purple'),title="Group",lwd=4, bty="n")

dev.off()

###APOE4 negative
tseq<-seq(0,4,0.5)
f0<-function(t)
{
pmatrix.msm(ADNI.APOE4.msm,t=t,covariates=list(APOE4_1=0),ci="normal")
}
Y<-lapply(tseq,f0)
q12<-q21<-q23<-matrix(0,length(tseq),2)
for(i in 1:length(tseq))
{
q12[i,1]<-Y[[i]]$estimates[1,2]
q21[i,1]<-Y[[i]]$estimates[2,1]
q23[i,1]<-Y[[i]]$estimates[2,3]
q12[i,2]<-(Y[[i]]$U[1,2]-Y[[i]]$L[1,2])/(2*1.96)
q21[i,2]<-(Y[[i]]$U[2,1]-Y[[i]]$L[2,1])/(2*1.96)
q23[i,2]<-(Y[[i]]$U[2,3]-Y[[i]]$L[2,3])/(2*1.96)
}

setEPS()
postscript("probabilityAPOE40.eps")

par(font=2,font.lab=2,font.axis=2,cex=1.2,bty = "n")
par(mar=c(4.1, 4.1, 2.1, 5.1), xpd=TRUE)
plot(tseq,q12[,1],xlim=c(0,4),ylim=c(0,0.8),xlab="Time on study (years)", ylab="Transition probability",lwd=4,type='b',lty=1,pch=1,col='red',axes=F,cex.lab=1.2,cex=1.2)
lines(tseq,q21[,1],type='b',lty=2,pch=2,col='blue',lwd=4)
lines(tseq,q23[,1],type='b',lty=3,pch=3,col='purple',lwd=4)
arrows(tseq, q12[,1]-q12[,2],tseq, q12[,1]+q12[,2], length=0.05, angle=90, code=3,col="red",lwd=2)
arrows(tseq, q21[,1]-q21[,2], tseq, q21[,1]+q21[,2], length=0.05, angle=90, code=3,col="blue",lwd=2)
arrows(tseq, q23[,1]-q23[,2], tseq, q23[,1]+q23[,2], length=0.05, angle=90, code=3,col="purple",lwd=2)
axis(1,lwd=4,cex.axis=1.2)
axis(2,lwd=4,cex.axis=1.2)
legend(x=c(0.1,0.4),y=c(0.6,0.8), legend=c("NC-MCI","MCI-NC","MCI-AD"), pch=c(1,2,3),lty=c(1,2,3),col=c('red','blue','purple'),title="Group",lwd=4, bty="n")

dev.off()


######################Survival probability

setEPS()
postscript("survivalAPOE4pof1.eps")

par(font=2,font.lab=2,font.axis=2,cex=1.2,bty = "n")
par(mar=c(5.1, 4.1, 4.1, 8.1), xpd=TRUE)
plot.survfit.msm(ADNI.APOE4.msm,from=1,covariates=list(APOE4_1=1),legend.pos=c(100,100),mark.time = TRUE,conf.int=FALSE,ci="normal",xlab="Screening time (years)",xlim=c(0,8),lwd=4,lty.ci=3,lwd.ci=4,lwd.surv=4,axes=F,cex.lab=1.2,cex=1.2)
legend("topright", inset=c(-0.45,0),legend=c("Fitted","Fitted CI","Empirical"),lty=c(1,2,3),col=c("red","red","blue"),lwd=4)
axis(1,lwd=4,cex.axis=1.2)
axis(2,lwd=4,cex.axis=1.2)

dev.off()

setEPS()
postscript("survivalAPOE4nef1.eps")

par(font=2,font.lab=2,font.axis=2,cex=1.2,bty = "n")
par(mar=c(5.1, 4.1, 4.1, 8.1), xpd=TRUE)
plot.survfit.msm(ADNI.APOE4.msm,from=1,covariates=list(APOE4_1=0),legend.pos=c(100,100),mark.time = TRUE,conf.int=FALSE,ci="normal",xlab="Screening time (years)",xlim=c(0,8),lwd=4,lty.ci=3,lwd.ci=4,lwd.surv=4,axes=F,cex.lab=1.2,cex=1.2)
legend("topright", inset=c(-0.45,0),legend=c("Fitted","Fitted CI","Empirical"),lty=c(1,2,3),col=c("red","red","blue"),lwd=4)
axis(1,lwd=4,cex.axis=1.2)
axis(2,lwd=4,cex.axis=1.2)

dev.off()

setEPS()
postscript("survivalAPOE4pof2.eps")

par(font=2,font.lab=2,font.axis=2,cex=1.2,bty = "n")
par(mar=c(5.1, 4.1, 4.1, 8.1), xpd=TRUE)
plot.survfit.msm(ADNI.APOE4.msm,from=2,covariates=list(APOE4_1=1),legend.pos=c(100,100),mark.time = TRUE,conf.int=FALSE,ci="normal",xlab="Screening time (years)",xlim=c(0,8),lwd=4,lty.ci=3,lwd.ci=4,lwd.surv=4,axes=F,cex.lab=1.2,cex=1.2)
legend("topright", inset=c(-0.45,0),legend=c("Fitted","Fitted CI","Empirical"),lty=c(1,2,3),col=c("red","red","blue"),lwd=4)
axis(1,lwd=4,cex.axis=1.2)
axis(2,lwd=4,cex.axis=1.2)

dev.off()


setEPS()
postscript("survivalAPOE4nef2.eps")

par(font=2,font.lab=2,font.axis=2,cex=1.2,bty = "n")
par(mar=c(5.1, 4.1, 4.1, 8.1), xpd=TRUE)
plot.survfit.msm(ADNI.msm,from=2,covariates=list(APOE4_1=0),legend.pos=c(100,100),mark.time = TRUE,conf.int=FALSE,ci="normal",xlab="Screening time (years)",xlim=c(0, 8),lwd=4,lty.ci=3,lwd.ci=4,lwd.surv=4,axes=F,cex.lab=1.2,cex=1.2)
legend("topright", inset=c(-0.45,0),legend=c("Fitted","Fitted CI","Empirical"),lty=c(1,2,3),col=c("red","red","blue"),lwd=4)
axis(1,lwd=4,cex.axis=1.2)
axis(2,lwd=4,cex.axis=1.2)

dev.off()
