#############################################################
######################Modeling data#########################
#############################################################


###########clear environment#######
rm(list=ls())


################loading package#################
library(msm)
library(MASS)

################set wroking directory
setwd("/path/to/my/directory")
mydata<-read.csv("balanced data 3 obs.csv")


mydata$APOE4<-factor(mydata$APOE4)

statetable.msm(DX,ID,data=mydata)


################Prediction function#############
################################Prediction function##############################

f<-function(model,test)
{
#	ncovar<-length(splitFormula(stan.mix1.msm$covariates,sep="+"))
	varname<-unlist(strsplit(gsub("[[:blank:]]", "", deparse(model$covariates[[2]])),split="[+]"))
	varlist<-subset(test,select=varname)
	choose<-unique(test$ID)
    P<-matrix(NA,dim(test)[1],dim(model$Qmatrices$baseline)[2])
    Q<-matrix(NA,dim(test)[1],dim(model$Qmatrices$baseline)[2])
    k<-1
    n<-0
    for(i in 1:length(choose))
    {
    	if(k<dim(test)[1])
    	{
    		# predict[k]<-NA
    		while(test[k,"ID"]==choose[i] && (test[k+1,"ID"]==choose[i]))
    		{
    			temp<-as.list(varlist[k,]) #need to change accordingly
                pm<-pmatrix.msm(model,t=test[k+1,"Years_bl"]-test[k,"Years_bl"],t1=test[k,"Years_bl"],covariates=temp,ci="none")
                qm<-qmatrix.msm(model, covariates=temp, sojourn=FALSE, ci="none")
		        pm<-pm[test[k,"DX"],]
		        qm<-qm[test[k,"DX"],] 
		        P[k+1,]<-pm
		        Q[k+1,]<-qm
		        # idx<-which(pm==max(pm), arr.ind = TRUE)
		        # predict[k+1]<-idx
		        # if(idx==test[k+1,"DX"])
		        # {
		        # 	n<-n+1
		        # }
		        k<-k+1
		        if(k==dim(test)[1])
		        {
		        	break
		        }
		    }
		    k<-k+1
		}
	}
	M<-data.frame(cbind(test$ID,test$DX,test$DXreal),row.names=NULL)
	colnames(M)<-c("ID","DX","DXreal")
	M$DXchar<-test$DXchar
    return(list(M=M,P=P,Q=Q))
}

#############Initializing###########

q2<-rbind(c(0,0.2),c(0,0))
rownames(q2)<-colnames(q2)<-c("MCI","AD")

################full data training#################

scale.mix.msm<-msm(DX~Years_bl,subject=ID,data=mydata,gen.inits=TRUE,covariates=~AGEreal+CDRSB+MMSE+APOE4+Ven_scale+Hip_scale+Who_scale+Ent_scale+Fus_scale+Mid_scale,qmatrix=q2,method="Nelder-Mead",control=list(maxit=20000))
outcome<-f(scale.mix.msm,mydata)
postdata0<-na.exclude(cbind(outcome$M,outcome$P,outcome$Q))
names(postdata0)[5:8]<-c("p11","p12","q11","q12")

boxplot(p12~DXreal,data=postdata0)
boxplot(q12~DXreal,data=postdata0)

doBy::summaryBy(p12~DXreal,data=postdata0,FUN=c(mean,length,quantile))
doBy::summaryBy(q12~DXreal,data=postdata0,FUN=c(mean,length,quantile))

quantile(postdata0$p12)
quantile(postdata0$q12)

pstat<-matrix(NA,19,5)

ladder<-seq(0.05,0.95,0.05)
for(i in 1:((0.95-0.05)/0.05+1))
{
    newp<-postdata0[(postdata0$p12>ladder[i]),]
    pstat[i,]<-c(ladder[i], length(unique(newp$ID)), length(unique(newp$ID[newp$DXreal==23])),length(unique(newp$ID[newp$DXreal==23]))/length(unique(newp$ID)),sum(newp$DXreal==23)/nrow(newp))

}

qstat<-matrix(NA,77,5)
ladder<-seq(0.15,3.95,0.05)
for(i in 1:((3.95-0.15)/0.05+1))
{
    newq<-postdata0[(postdata0$q12>ladder[i]),]
    qstat[i,]<-c(ladder[i], length(unique(newq$ID)), length(unique(newq$ID[newq$DXreal==23])),length(unique(newq$ID[newq$DXreal==23]))/length(unique(newq$ID)),sum(newq$DXreal==23)/nrow(newq))

}


stat<-matrix(NA,19*77,6)
ladder1<-seq(0.05,0.95,0.05)
ladder2<-seq(0.15,3.95,0.05)
k<-1
for(i in 1:((0.95-0.05)/0.05+1))
{
    for(j in 1:((3.95-0.15)/0.05+1))
    {
        new<-postdata0[(postdata0$p12>ladder1[i]) | (postdata0$q12>ladder2[j]),]
        stat[k,]<-c(ladder1[i], ladder2[j],length(unique(new$ID)), length(unique(new$ID[new$DXreal==23])),length(unique(new$ID[new$DXreal==23]))/length(unique(new$ID)),sum(new$DXreal==23)/nrow(new))
        k<-k+1
    }
      
}

stat<-as.data.frame(stat)

new<-postdata0[(postdata0$p12>0.5) | (postdata0$q12>1.5),]

################leave one out#################

choose<-unique(mydata$ID)
logistic<-list()
TP<-FN<-FP<-TN<-0
coef<-matrix(0,length(choose),3)
final<-NULL
for(j in 1:length(choose))
{
	subdata1<-mydata[which(mydata$ID!=choose[j]),]
	subdata2<-subset(mydata,ID==choose[j])

    #########training model###########
	scale.mix.msm<-msm(DX~Years_bl,subject=ID,data=subdata1,gen.inits=TRUE,covariates=~MMSE+APOE4+Ven_scale+Hip_scale+Who_scale+Ent_scale+Fus_scale+Mid_scale,qmatrix=q2,method="Nelder-Mead",control=list(maxit=20000))
    outcome<-f(scale.mix.msm,subdata1)
    postdata<-na.exclude(cbind(outcome$M,outcome$P,outcome$Q))
    names(postdata)[5:8]<-c("p11","p12","q11","q12")
    postdata$DX<-postdata$DX-1
    logistic[[j]]<-glm(DX~p12+q12, data = postdata, family = "binomial")
#   summary(logistic[[j]])
    coef[j,]<-logistic[[j]]$coefficients
    #########testing data###########
    out<-f(scale.mix.msm,subdata2)
    post<-na.exclude(cbind(out$M,out$P,out$Q))
    names(post)[5:8]<-c("p11","p12","q11","q12")
    score<-predict.glm(logistic[[j]],newdata=data.frame(p12=post$p12,q12=post$q12),type="link")
    pred<-(score>0)+1
    post<-cbind(post,score,pred)
    final<-rbind(final,post)
    for(t in 1:dim(post)[1])
    {
    	if(post$DX[t]==2)
    	{
    		if(post$pred[t]==2)
    		{
    			TP<-TP+1
    		}
    		else
    		{
    			FN<-FN+1
    		}
    	}
    	else
    	{
    		if(post$pred[t]==2)
    		{
    			FP<-FP+1
    		}
    		else
    		{
    			TN<-TN+1
    		}
    	}
    }
}

sensitivity<-TP/(TP+FN)
specificity<-TN/(TN+FP)
precision<-TP/(TP+FP)
accuracy<-(TP+TN)/(TP+FP+FN+TN)

#############################full search########################
################################################################

fullid<-unique(mydata$ID)

extract_data<-function(x)
{
    return(subset(mydata,ID==x))
}


stat<-matrix(NA,8*8,10)
ladder1<-seq(0.35,0.7,0.05)
ladder2<-seq(0.8,1.5,0.1)

k<-1
for(i1 in 1:8)
{
    for(i2 in 1:8)
    {
        new<-postdata0[(postdata0$p12>ladder1[i1]) | (postdata0$q12>ladder2[i2]),]
        choose<-unique(new$ID)
        dataget<-apply(as.matrix(choose),1,extract_data)
        data<-do.call(rbind,dataget)


logistic<-list()
TP<-FN<-FP<-TN<-0
coef<-matrix(0,length(choose),3)
final<-NULL
for(j in 1:length(choose))
{
    subdata1<-data[which(data$ID!=choose[j]),]
    subdata2<-subset(data,ID==choose[j])

    #########training model###########
    scale.mix.msm<-msm(DX~Years_bl,subject=ID,data=subdata1,gen.inits=TRUE,covariates=~AGEreal+CDRSB+MMSE+APOE4+Ven_scale+Hip_scale+Who_scale+Ent_scale+Fus_scale+Mid_scale,qmatrix=q2,method="Nelder-Mead",control=list(maxit=20000))
    outcome<-f(scale.mix.msm,subdata1)
    postdata<-na.exclude(cbind(outcome$M,outcome$P,outcome$Q))
    names(postdata)[5:8]<-c("p11","p12","q11","q12")
    postdata$DX<-postdata$DX-1
    logistic[[j]]<-glm(DX~p12+q12, data = postdata, family = "binomial")
#   summary(logistic[[j]])
    coef[j,]<-logistic[[j]]$coefficients
    #########testing data###########
    out<-f(scale.mix.msm,subdata2)
    post<-na.exclude(cbind(out$M,out$P,out$Q))
    names(post)[5:8]<-c("p11","p12","q11","q12")
    score<-predict.glm(logistic[[j]],newdata=data.frame(p12=post$p12,q12=post$q12),type="link")
    pred<-(score>0)+1
    post<-cbind(post,score,pred)
    final<-rbind(final,post)
    for(t in 1:dim(post)[1])
    {
        if(post$DX[t]==2)
        {
            if(post$pred[t]==2)
            {
                TP<-TP+1
            }
            else
            {
                FN<-FN+1
            }
        }
        else
        {
            if(post$pred[t]==2)
            {
                FP<-FP+1
            }
            else
            {
                TN<-TN+1
            }
        }
    }
}

sensitivity<-TP/(TP+FN)
specificity<-TN/(TN+FP)
precision<-TP/(TP+FP)
accuracy<-(TP+TN)/(TP+FP+FN+TN)


        stat[k,]<-c(ladder1[i1],ladder2[i2],length(unique(new$ID)), length(unique(new$ID[new$DXreal==23])),length(unique(new$ID[new$DXreal==23]))/length(unique(new$ID)),sum(new$DXreal==23)/nrow(new),sensitivity,specificity,precision,accuracy)
        k<-k+1
    }
      
}



#############################2 group prediction########################

new<-postdata0[(postdata0$p12>0.6) | (postdata0$q12>1.2),]
subid<-unique(new$ID)
fullid<-unique(mydata$ID)
leftid<-fullid[!fullid %in% subid]

mydata[,c("Ven_scale","Hip_scale","Who_scale","Ent_scale","Fus_scale","Mid_scale","Ven_stan")]<-1/100*mydata[,c("Ven_scale","Hip_scale","Who_scale","Ent_scale","Fus_scale","Mid_scale","Ven_stan")]

extract_data<-function(x)
{
    return(subset(mydata,ID==x))
}

dataget<-apply(as.matrix(subid),1,extract_data)
data11<-do.call(rbind,dataget)

dataget<-apply(as.matrix(leftid),1,extract_data)
data22<-do.call(rbind,dataget)


################################################################

choose<-subid
logistic<-list()
TP<-FN<-FP<-TN<-0
coef<-matrix(0,length(choose),3)
final<-NULL
for(j in 1:length(choose))
{
    subdata1<-data11[which(data11$ID!=choose[j]),]
    subdata2<-subset(data11,ID==choose[j])

    #########training model###########
    scale.mix.msm<-msm(DX~Years_bl,subject=ID,data=subdata1,gen.inits=TRUE,covariates=~AGEreal+CDRSB+MMSE+APOE4+Ven_scale+Hip_scale+Who_scale+Ent_scale+Fus_scale+Mid_scale,qmatrix=q2,method="Nelder-Mead",control=list(maxit=20000))
    outcome<-f(scale.mix.msm,subdata1)
    postdata<-na.exclude(cbind(outcome$M,outcome$P,outcome$Q))
    names(postdata)[5:8]<-c("p11","p12","q11","q12")
    postdata$DX<-postdata$DX-1
    logistic[[j]]<-glm(DX~p12+q12, data = postdata, family = "binomial")
#   summary(logistic[[j]])
    coef[j,]<-logistic[[j]]$coefficients
    #########testing data###########
    out<-f(scale.mix.msm,subdata2)
    post<-na.exclude(cbind(out$M,out$P,out$Q))
    names(post)[5:8]<-c("p11","p12","q11","q12")
    score<-predict.glm(logistic[[j]],newdata=data.frame(p12=post$p12,q12=post$q12),type="link")
    pred<-(score>0)+1
    post<-cbind(post,score,pred)
    final<-rbind(final,post)
    for(t in 1:dim(post)[1])
    {
        if(post$DX[t]==2)
        {
            if(post$pred[t]==2)
            {
                TP<-TP+1
            }
            else
            {
                FN<-FN+1
            }
        }
        else
        {
            if(post$pred[t]==2)
            {
                FP<-FP+1
            }
            else
            {
                TN<-TN+1
            }
        }
    }
}

sensitivity<-TP/(TP+FN)
specificity<-TN/(TN+FP)
precision<-TP/(TP+FP)
accuracy<-(TP+TN)/(TP+FP+FN+TN)


###########################################

choose<-leftid
logistic<-list()
TP<-FN<-FP<-TN<-0
coef<-matrix(0,length(choose),3)
final<-NULL
for(j in 1:length(choose))
{
    subdata1<-data22[which(data22$ID!=choose[j]),]
    subdata2<-subset(data22,ID==choose[j])

    #########training model###########
    scale.mix.msm<-msm(DX~Years_bl,subject=ID,data=subdata1,gen.inits=TRUE,covariates=~AGEreal+CDRSB+MMSE+APOE4+Ven_scale+Hip_scale+Who_scale+Ent_scale+Fus_scale+Mid_scale,qmatrix=q2,method="Nelder-Mead",control=list(maxit=20000))
    outcome<-f(scale.mix.msm,subdata1)
    postdata<-na.exclude(cbind(outcome$M,outcome$P,outcome$Q))
    names(postdata)[5:8]<-c("p11","p12","q11","q12")
    postdata$DX<-postdata$DX-1
    logistic[[j]]<-glm(DX~p12+q12, data = postdata, family = "binomial")
#   summary(logistic[[j]])
    coef[j,]<-logistic[[j]]$coefficients
    #########testing data###########
    out<-f(scale.mix.msm,subdata2)
    post<-na.exclude(cbind(out$M,out$P,out$Q))
    names(post)[5:8]<-c("p11","p12","q11","q12")
    score<-predict.glm(logistic[[j]],newdata=data.frame(p12=post$p12,q12=post$q12),type="link")
    pred<-(score>0)+1
    post<-cbind(post,score,pred)
    final<-rbind(final,post)
    for(t in 1:dim(post)[1])
    {
        if(post$DX[t]==2)
        {
            if(post$pred[t]==2)
            {
                TP<-TP+1
            }
            else
            {
                FN<-FN+1
            }
        }
        else
        {
            if(post$pred[t]==2)
            {
                FP<-FP+1
            }
            else
            {
                TN<-TN+1
            }
        }
    }
}

sensitivity<-TP/(TP+FN)
specificity<-TN/(TN+FP)
precision<-TP/(TP+FP)
accuracy<-(TP+TN)/(TP+FP+FN+TN)


